==> haskell-memotrie-0.6.9-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-HWBZ1Ykm7kbEs62OF2Qxfp
key: MemoTrie-0.6.9-HWBZ1Ykm7kbEs62OF2Qxfp
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: bbb171904dffc0a6b5b89c427576c593
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-HWBZ1Ykm7kbEs62OF2Qxfp
depends:
    base-4.12.0.0 newtype-generics-0.5.3-8vRAVe3b0uzEPVesdtW5pJ
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.9-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-54uMvJxUICq8bkEFlpMsAY
key: MemoTrie-0.6.9-54uMvJxUICq8bkEFlpMsAY
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: 619b2b5d61d518edee892a8f3cdb087e
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-54uMvJxUICq8bkEFlpMsAY
depends:
    base-4.12.0.0 newtype-generics-0.5.3-52wiJJwplpd8IuCefAFSTL
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
